.. DORAnet documentation master file, created by
   sphinx-quickstart on Fri Apr 26 13:23:15 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DORAnet's documentation!
===================================
DORAnet (Designing Optimal Reaction Avenues Network Enumeration Tool) is a
rework of both `minedatabase <https://pypi.org/project/minedatabase/>`_ and
`NetGen <https://github.com/BroadbeltLab/NetGen>`_. It is intended to streamline
and extend the implementation of chemical reaction network generation for
research purposes.

Check out the :doc:`usage` section for further information.

.. toctree::
   :maxdepth: 2

   tutorials
   usage
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
